@@ -104,9 +104,10 @@ class Session(object):
                                    'radical.pilot module to analyze this '
                                    'session - please install it.') from e
 
-            self._profile, accuracy, hostmap \
-                              = rpu.get_session_profile    (sid=sid, src=self._src)
-            self._description = rpu.get_session_description(sid=sid, src=self._src)
+            self._profile, accuracy, hostmap = \
+                    rpu.get_session_profile(sid=sid, src=self._src)
+            self._description = \
+                    rpu.get_session_description(sid=sid, src=self._src)
 
             self._description['accuracy'] = accuracy
             self._description['hostmap']  = hostmap
@@ -179,7 +180,7 @@ class Session(object):
 
         elif os.path.isfile(src):
 
-            # src is afile - we assume its a tarball and extract it
+            # src is a file - we assume its a tarball and extract it
             if  src.endswith('.prof'):
                 # use as is
                 tgt = src
@@ -372,8 +373,11 @@ class Session(object):
         entity_events = dict()
 
         for event in profile:
-            uid = event[ru.UID]
 
+            if event[ru.TIME] < -1:  # allow fow 1sec rounding error
+                raise ValueError('invalid time stamp: %s' % event)
+
+            uid = event[ru.UID]
             if uid not in entity_events:
                 entity_events[uid] = list()
             entity_events[uid].append(event)
@@ -471,18 +475,11 @@ class Session(object):
         # iterate through all self._entities and collect UIDs of all entities
         # which match the given set of filters (after removing all events which
         # are not in the given time ranges)
-        if not etype: etype = list()
-        if not uid  : uid   = list()
-        if not state: state = list()
-        if not event: event = list()
-        if not time : time  = list()
-
-        if etype and not isinstance(etype, list): etype = [etype]
-        if uid   and not isinstance(uid  , list): uid   = [uid  ]
-        if state and not isinstance(state, list): state = [state]
-        if event and not isinstance(event, list): event = [event]
-
-        if time and len(time) and not isinstance(time[0], list): time = [time]
+        etype = ru.as_list(etype)
+        uid   = ru.as_list(uid  )
+        state = ru.as_list(state)
+        event = ru.as_list(event)
+        time  = ru.as_list(time )
 
         ret = list()
         for eid,entity in list(self._entities.items()):
@@ -752,7 +749,7 @@ class Session(object):
 
            session.duration(state=[rp.NEW, rp.FINAL]))
 
-        where `rp.FINAL` is a list of final unit states.
+        where `rp.FINAL` is a list of final task states.
         '''
 
         if not ranges:
@@ -776,7 +773,7 @@ class Session(object):
         '''
         This method accepts the same set of parameters as the `ranges()` method,
         and will use the `ranges()` method to obtain a set of ranges.  It will
-        return a time series, counting the number of units which are
+        return a time series, counting the number of tasks which are
         concurrently matching the ranges filter at any point in time.
 
         The additional parameter `sampling` determines the exact points in time
@@ -798,7 +795,7 @@ class Session(object):
 
         Example::
 
-            session.filter(etype='unit').concurrency(state=[rp.AGENT_EXECUTING,
+            session.filter(etype='task').concurrency(state=[rp.AGENT_EXECUTING,
                 rp.AGENT_STAGING_OUTPUT_PENDING])
 
         '''
@@ -903,7 +900,7 @@ class Session(object):
 
         Example::
 
-           session.filter(etype='unit').rate(state=[rp.AGENT_EXECUTING])
+           session.filter(etype='task').rate(state=[rp.AGENT_EXECUTING])
         '''
 
         timestamps = self.timestamps(event=event, state=state, time=time,
@@ -1018,7 +1015,7 @@ class Session(object):
                                            (box[3] - box[2]  + 1)
 
         info  = ''
-        info += '%s [%d]\n' % (self.uid, len(self.get(etype='unit')))
+        info += '%s [%d]\n' % (self.uid, len(self.get(etype='task')))
 
         for metric in metrics + ['total']:
             if isinstance(metric, list):
@@ -1114,7 +1111,7 @@ class Session(object):
     #     Example::
 
     #         s.utilization(owner          = 'pilot',
-    #                       consumer       = 'unit',
+    #                       consumer       = 'task',
     #                       resource       = 'cores',
     #                       owner_events   = [{ru.EVENT: 'bootstrap_0_start'},
     #                                         {ru.EVENT: 'bootstrap_0_stop' }])
@@ -1315,14 +1312,14 @@ class Session(object):
 
             usage('pilot', [{ru.STATE: None, ru.EVENT: 'bootstrap_0_start'},
                             {ru.STATE: None, ru.EVENT: 'bootstrap_0_stop' }],
-                  'unit' , [{ru.STATE: None, ru.EVENT: 'schedule_ok'      },
+                  'task' , [{ru.STATE: None, ru.EVENT: 'schedule_ok'      },
                             {ru.STATE: None, ru.EVENT: 'unschedule_stop'  }],
-                  'unit' , [{ru.STATE: None, ru.EVENT: 'exec_start'       },
+                  'task' , [{ru.STATE: None, ru.EVENT: 'exec_start'       },
                             {ru.STATE: None, ru.EVENT: 'exec_stop'        }])
         '''
 
         # this is currently only supported for RP sessions, as we only know for
-        # pilots and units how to dig resource information out of session and
+        # pilots and tasks how to dig resource information out of session and
         # entity metadata.
         assert(self.stype == 'radical.pilot'), \
                'stype %s unsupported' % self._stype
@@ -1370,7 +1367,7 @@ class Session(object):
                 return [[[res_idx[entity.uid]['_min'],
                           res_idx[entity.uid]['_max']]], []]
 
-            elif entity.etype == 'unit':
+            elif entity.etype == 'task':
 
                 # find owning pilot
                 pid = entity.cfg.get('pilot')
